#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar  8 10:31:19 2017

@author: stefanloock
"""
from pyprProcessors import *
from pyprUtilities import *
import numpy as np
import matplotlib.pyplot as plt
from pyprAlgorithms import *
from simulatedDataCellImage import *

#%%
input_data = simulatedDataCellImage()

input_data["algorithm"]["maxit"] = 2500
input_data["algorithm"]["error"] = 1e-4
input_data["algorithm"]["metric"] = "norm"

input_data["system"] = pySL.SLgetShearletSystem2D(0,256,256,3)

input_data["initialGuess"] = wavePropagator(input_data, input_data["problem"]["data"], -1)


# Compare different constraints:
#%% Shearlet soft-thresholding with range constraint:
input_data["problem"]["constraint"]["name"] = "shearlet thresholding and range"
input_data["problem"]["constraint"]["info"] = "soft thresholding"
input_data["problem"]["constraint"]["parameter"] = "constant"
input_data["problem"]["constraint"]["gamma0"] = 0.005

recDataShearletRangeSoft = RAAR(input_data)

#%% Shearlet smooth-hard-thresholding:
input_data["problem"]["constraint"]["name"] = "shearlet thresholding"
input_data["problem"]["constraint"]["info"] = "smooth hard"
input_data["problem"]["constraint"]["parameter"] = "constant"
input_data["problem"]["constraint"]["gamma0"] = 0.007

recDataShearletSmoothHard = RAAR(input_data)

#%% Support and range constraint:
input_data["problem"]["constraint"]["name"] = "support and range"
if 'info' in input_data["problem"]["constraint"]:
    del input_data["problem"]["constraint"]["info"]

recDataSupportRange = RAAR(input_data)

#%% Plot reconstruction results:
fig = plt.figure()
a = fig.add_subplot(3,1,1)
imga = plt.imshow(np.angle(recDataShearletRangeSoft["reconstruction"]))
a.set_title('Shearlet Soft-Thresholding and Range')
plt.colorbar()
b = fig.add_subplot(3,1,2)
imgb = plt.imshow(np.angle(recDataShearletSmoothHard["reconstruction"]))
b.set_title('Shearlet Smooth-Hard-Thresholding')
plt.colorbar()
c = fig.add_subplot(3,1,3)
imgc = plt.imshow(np.angle(recDataSupportRange["reconstruction"]))
c.set_title('Support and Range')
plt.colorbar()
plt.show()


#%% Plot error decay:
f, axarr = plt.subplots(3, sharex=True)
axarr[0].plot(recDataShearletRangeSoft["error"])
axarr[0].set_title('Error decay: Shearlet Soft-Thresholding and Range')
axarr[1].plot(recDataShearletSmoothHard["error"])
axarr[1].set_title('Error decay: Shearlet Smooth-Hard-Thresholding')
axarr[2].plot(recDataSupportRange["error"])
axarr[2].set_title('Error decay: Support and Range')
